BlePeerUuidGenerator class abstract final

Derives stable BLE UUIDs from appName so every install of the same app can find each other.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

configFor(String appName, {String deviceNamePrefix = ''}) BlePeerConfig
uuidFor({required String appName, required String kind}) String