PeerDisconnectInfo class final

Emitted when an established session ends for any reason.

Annotations

Constructors

PeerDisconnectInfo({required PeerDisconnectReason reason, PeerEndpoint? remotePeer})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
reason PeerDisconnectReason
final
remotePeer PeerEndpoint?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited