PeerUser class final

The local or remote player visible to your app (not a BLE/GATT concept).

Annotations

Constructors

PeerUser({required String id, required String displayName, String? deviceLabel})
const
PeerUser.fromEndpoint(PeerEndpoint endpoint)
factory

Properties

deviceLabel String?
Shown to nearby devices during advertising. Defaults to displayName.
final
displayName String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toEndpoint({String? deviceId}) PeerEndpoint
Builds the wire PeerEndpoint used internally by the transport layer.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited